import java.awt.image.BufferedImage;
import java.awt.Graphics2D;
import java.net.URL;
import javax.imageio.ImageIO;

public class Imager
{
    //////////////////////////
    // image helper methods //
    //////////////////////////
    
    public static BufferedImage loadImage(String filename)
    {
        BufferedImage image;
        try
        {
            URL fileLocation = (new Imager()).getClass().getClassLoader().getResource(filename);
            image = ImageIO.read( fileLocation );
        } 
        catch (Exception e)
        {
            image = null;
            System.err.println("ERROR: Could not load file: " + filename);
        }
        return image;
    } 
    
     public static BufferedImage rotateImage(BufferedImage originalImage, double rotateAngle) 
     {
        double sinAngle = Math.abs(Math.sin(Math.toRadians(rotateAngle)));
        double cosAngle = Math.abs(Math.cos(Math.toRadians(rotateAngle)));
        int originalWidth = originalImage.getWidth();
        int originalHeight = originalImage.getHeight();
        int newWidth  = (int)Math.floor(originalWidth*cosAngle  + originalHeight*sinAngle);
        int newHeight = (int)Math.floor(originalHeight*cosAngle + originalWidth*sinAngle);
        BufferedImage newImage = new BufferedImage(newWidth, newHeight, 
            BufferedImage.TYPE_INT_ARGB);
        Graphics2D newGraphics = newImage.createGraphics();
        newGraphics.translate((newWidth-originalWidth)/2, (newHeight-originalHeight)/2);
        newGraphics.rotate(rotateAngle, originalWidth/2, originalHeight/2);
        newGraphics.drawRenderedImage(originalImage, null);
        newGraphics.dispose();
        return newImage;
    }

    public static BufferedImage scaleImage(BufferedImage originalImage, double scaleFactor)
    {
        int originalWidth = originalImage.getWidth();
        int originalHeight = originalImage.getHeight();
        int newWidth  = (int)(scaleFactor * originalWidth);
        int newHeight = (int)(scaleFactor * originalHeight);
        BufferedImage newImage = new BufferedImage(newWidth, newHeight, 
            BufferedImage.TYPE_INT_ARGB);
        Graphics2D newGraphics = newImage.createGraphics();
        newGraphics.scale(scaleFactor, scaleFactor);
        newGraphics.drawRenderedImage(originalImage, null);
        newGraphics.dispose();
        return newImage;
    } 
}