import java.awt.Graphics2D;
/**
 *   The Scene class works together with the GameManager class
 *   to help create games with multiple "screens" -- these could be
 *   different menus (start, instructions, game over, etc.), 
 *   levels or stages within a game, inventory screens, etc.
 *   
 *   The GameManager class handles functions common to every game:
 *   creation of the window,
 *   running the game loop, 
 *   calculating elapsed time,
 *   storing keyboard input,
 *   and rendering graphics to the window (double buffering).
 *   
 *   A Scene contains game-specific code and must contain the
 *   following four methods (even if they are blank) in order
 *   to work correctly with the GameManager class.
 *   This class is meant to be extended by specific games;
 *   Scenes are the types of classes that can be loaded by the GameManager.
 */
abstract class Scene
{
    /** initialize variables, load graphics, etc. */
    abstract void load();
    
    /** update logic for this scene */
    abstract void update(double dt);
    
    /** redraw everything on screen */
    abstract void draw(Graphics2D g);
    
    /** store global variables, etc. */ 
    abstract void unload();
}